@@ -171,10 +171,14 @@ activate (GApplication *application)
 	/* Create the interface. */
 	if (self->window == NULL) {
 		HitoriUndo *undo;
+		gchar *size_str;
 
 		/* Setup */
 		self->debug = priv->debug;
-		self->board_size = DEFAULT_BOARD_SIZE;
+		self->settings = g_settings_new ("org.gnome.hitori");
+		size_str = g_settings_get_string (self->settings, "board-size");
+		self->board_size = g_ascii_strtoull (size_str, NULL, 10);
+		g_free (size_str);
 
 		undo = g_new0 (HitoriUndo, 1);
 		undo->type = UNDO_NEW_GAME;
@@ -293,9 +297,15 @@ hitori_set_board_size (Hitori *hitori, guint board_size)
 		GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (hitori->window),
 				GTK_DIALOG_MODAL,
 				GTK_MESSAGE_QUESTION,
-				GTK_BUTTONS_YES_NO,
+				GTK_BUTTONS_NONE,
 				_("Do you want to stop the current game?"));
-		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_YES) {
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					_("Keep _Playing"), GTK_RESPONSE_REJECT,
+					_("_New Game"), GTK_RESPONSE_ACCEPT,
+					NULL);
+
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_ACCEPT) {
 			gtk_widget_destroy (dialog);
 			return;
 		}
@@ -366,9 +376,10 @@ hitori_disable_events (Hitori *hitori)
 static void
 set_timer_label (Hitori *hitori)
 {
-	/* Translators: this is the format for the timer label. The first parameter is the number of minutes which have elapsed since the start of the
-	 * game; the second parameter is the number of seconds. */
-	gchar *text = g_strdup_printf (_("Time: %02u:%02u"), hitori->timer_value / 60, hitori->timer_value % 60);
+	/* Translators: this is the format for the timer label. The first parameter is the number of minutes which have
+         * elapsed since the start of the game; the second parameter is the number of seconds. In between is the ratio
+         * character and a LTR mark to force minutes on the left in RTL locales. You can probably leave this unchanged. */
+	gchar *text = g_strdup_printf (_("%02u\xE2\x88\xB6\xE2\x80\x8E%02u"), hitori->timer_value / 60, hitori->timer_value % 60);
 	gtk_label_set_text (hitori->timer_label, text);
 	g_free (text);
 }
@@ -429,6 +440,8 @@ hitori_quit (Hitori *hitori)
 	if (hitori->painted_font_desc != NULL)
 		pango_font_description_free (hitori->painted_font_desc);
 
+	g_object_unref (hitori->settings);
+
 	g_application_quit (G_APPLICATION (hitori));
 }
 
